==> custom_pages-v1.12.13.zip: custom_pages/messages/fr/view.php <==
<?php

return [
    '<strong>Copy</strong> Custom Page' => '<strong>Copier</strong> une page personnalisée',
    '<strong>Info: </strong> Pages marked as "Admin Only" are not shown in the stream!' => '<strong>Info : </strong>Les pages marquées comme "Administrateurs uniquement" ne sont pas affichées dans le fil d’actualités.',
    'Add new {pageType}' => 'Ajouter {pageType}',
    'By setting an url shortcut value, you can create a better readable url for your page. If <b>URL Rewriting</b> is enabled on your site, the value \'mypage\' will result in an url \'www.example.de/p/mypage\'.' => 'En définissant un raccourci d\'url, vous pouvez créer une url plus lisible pour votre page. Si la <b>Réécriture d\'URL</b> est activée pour votre site, et que vous choisissez le raccourci "mapage" par exemple, votre page sera accessible à l\'adresse "www.example.net/p/mapage".',
    'Configuration' => 'Configuration',
    'Copy' => 'Copier',
    'Create' => 'Créer',
    'Create new template' => 'Créer un nouveau modèle',
    'Delete' => 'Supprimer',
    'Edit template' => 'Modifier le modèle',
    'Empty' => 'Vide',
    'Here you can configure the general settings of your {pageLabel}.' => 'Ici, vous pouvez configurer les réglages généraux de votre {pageLabel}.',
    'Inline Editor' => 'Éditeur en ligne',
    'Multiple' => 'Multiple',
    'Open page...' => 'Ouvrir la page...',
    'Page configuration' => 'Configuration de la page',
    'Save' => 'Enregistrer',
    'Settings' => 'Paramètres',
    'The abstract will be used as stream entry content to promote the actual page. 
                        If no abstract is given or the page is only visible for admins, no stream entry will be created.' => 'Le résumé sera utilisé comme texte dans une entrée du fil d’actualités pour mettre en valeur la page en question. Si aucun résumé n’est défini ou si la page est visible uniquement par les administrateurs et administratrices, aucune entrée ne sera créée dans le fil d’activités.',
    'This page lists all available custom content entries.' => 'Cette page présente toutes les entrées disponibles de documents personnalisés.',
    'View not found' => 'Vue non trouvée',
    'You need to be a system administrator to edit this URL' => 'Vous devez avoir un rôle d’administration pour modifier cette URL.',
    'e.g. allowfullscreen allow="camera; microphone"' => 'par exemple  allowfullscreen allow="camera; microphone"',
    'e.g. http://www.example.de' => 'p.ex. https://www.exemple.net',
    'none' => 'aucune',
    'Exit Edit Mode' => '',
    'This section has no editable elements.' => '',
    'You don\'t have permission to access the page' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/fr/view.php <==
<?php

return [
    '<strong>Copy</strong> Custom Page' => '<strong>Copier</strong> une page personnalisée',
    '<strong>Info: </strong> Pages marked as "Admin Only" are not shown in the stream!' => '<strong>Info : </strong>Les pages marquées comme "Administrateurs uniquement" ne sont pas affichées dans le fil d’actualités.',
    'Add new {pageType}' => 'Ajouter {pageType}',
    'By setting an url shortcut value, you can create a better readable url for your page. If <b>URL Rewriting</b> is enabled on your site, the value \'mypage\' will result in an url \'www.example.de/p/mypage\'.' => 'En définissant un raccourci d\'url, vous pouvez créer une url plus lisible pour votre page. Si la <b>Réécriture d\'URL</b> est activée pour votre site, et que vous choisissez le raccourci "mapage" par exemple, votre page sera accessible à l\'adresse "www.example.net/p/mapage".',
    'Configuration' => 'Configuration',
    'Copy' => 'Copier',
    'Create' => 'Créer',
    'Create new template' => 'Créer un nouveau modèle',
    'Delete' => 'Supprimer',
    'Edit template' => 'Modifier le modèle',
    'Empty' => 'Vide',
    'Here you can configure the general settings of your {pageLabel}.' => 'Ici, vous pouvez configurer les réglages généraux de votre {pageLabel}.',
    'Inline Editor' => 'Éditeur en ligne',
    'Multiple' => 'Multiple',
    'Open page...' => 'Ouvrir la page...',
    'Page configuration' => 'Configuration de la page',
    'Save' => 'Enregistrer',
    'Settings' => 'Paramètres',
    'This page lists all available custom content entries.' => 'Cette page présente toutes les entrées disponibles de documents personnalisés.',
    'View not found' => 'Vue non trouvée',
    'You need to be a system administrator to edit this URL' => 'Vous devez avoir un rôle d’administration pour modifier cette URL.',
    'e.g. allowfullscreen allow="camera; microphone"' => 'par exemple  allowfullscreen allow="camera; microphone"',
    'e.g. http://www.example.de' => 'p.ex. https://www.exemple.net',
    'none' => 'aucune',
    'Exit Edit Mode' => '',
    'The abstract will be used as stream entry content to promote the actual page.
                        If no abstract is given or the page is only visible for admins, no stream entry will be created.' => '',
    'This section has no editable elements.' => '',
    'You don\'t have permission to access the page' => '',
];
